@@ -91,6 +91,8 @@ mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0023 ), "MrAcquisitionType",
 mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0024 ), "SequenceName",                                "SH" ));
 mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0025 ), "AngioFlag",                                   "CS" ));
 mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0050 ), "SliceThickness",                              "DS" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0070 ), "CountsAccumulated",                           "IS" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0071 ), "AcquisitionTerminationCondition",             "CS" ));
 mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0080 ), "RepetitionTime",                              "DS" ));
 mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0081 ), "EchoTime",                                    "DS" ));
 mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x0082 ), "InversionTime",                               "DS" ));
@@ -127,6 +129,7 @@ mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1100 ), "ReconstructionDiameter",
 mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1149 ), "FovDimensions",                               "IS" ));
 mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1200 ), "LastCalibrationDate",                         "DA" ));
 mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1201 ), "LastCalibrationTime",                         "TM" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1210 ), "ConvolutionKernel",                           "SH" ));
 mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1250 ), "ReceivingCoil",                               "SH" ));
 mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1251 ), "TransmittingCoil",                            "SH" ));
 mAddEntry (DicomElement ( DicomTag ( 0x0018, 0x1310 ), "AcquisitionMatrix",                           "US" ));
@@ -368,6 +371,24 @@ mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x2010 ), "OrderCallbackPhoneNumber
 mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x2400 ), "ImagingServiceRequestComments",               "LT" ));
 mAddEntry (DicomElement ( DicomTag ( 0x0040, 0x9210 ), "LUTLabel",                                    "SH" ));
 mAddEntry (DicomElement ( DicomTag ( 0x0040, 0xa170 ), "PurposeOfReferenceCodeSequence",              "SQ" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0011 ), "NumberOfEnergyWindows",                       "US" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0012 ), "EnergyWindowInformationSequence",             "SQ" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0016 ), "RadiopharmaceuticalInformationSequence",      "SQ" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0020 ), "DetectorVector",                              "US" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0021 ), "NumberOfDetectors",                           "US" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0022 ), "DetectorInformationSequence",                 "SQ" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0050 ), "RotationVector",                              "US" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0051 ), "NumberOfRotations",                           "US" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0052 ), "RotationInformationSequence",                 "SQ" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0080 ), "SliceVector",                                 "US" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0081 ), "NumberOfSlices",                              "US" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0090 ), "AngularViewVector",                           "US" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0202 ), "TypeOfDetectorMotion",                        "CS" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0400 ), "ImageID",                                     "SH" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0410 ), "PatientOrientationCodeSequence",              "SQ" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0414 ), "PatientGantryRelationshipCodeSequence",       "SQ" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x0500 ), "SliceProgressionDirection",                   "CS" ));
+mAddEntry (DicomElement ( DicomTag ( 0x0054, 0x1103 ), "ReconstructionMethod",                        "LO" ));
 mAddEntry (DicomElement ( DicomTag ( 0x0088, 0x0140 ), "StorageMediaFilesetUid",                      "UI" ));
 mAddEntry (DicomElement ( DicomTag ( 0x0088, 0x0200 ), "IconImageSequence",                           "SQ" ));
 mAddEntry (DicomElement ( DicomTag ( 0x2050, 0x0020 ), "PresentationLutShape",                        "CS" ));
