@@ -127,19 +127,19 @@ void
 Dictionary::Init()
 {
   if (mFilename.compare (fnDicom) == 0) {
-    std::cout << "fnDicom" << std::endl;
+ //   std::cout << "fnDicom" << std::endl;
 #include "DicomDictionary.h"
   } else if (mFilename.compare (fnExcite) == 0) {
-    std::cout << "fnExcite" << std::endl;
+  //  std::cout << "fnExcite" << std::endl;
 #include "ExciteDictionary.h"
   } else if (mFilename.compare (fnNumaris) == 0) {
-    std::cout << "fnNumaris" << std::endl;
+   // std::cout << "fnNumaris" << std::endl;
 #include "NumarisDictionary.h"
   } else if (mFilename.compare (fnPhilips) == 0) {
-    std::cout << "fnPhilips" << std::endl;
+  //  std::cout << "fnPhilips" << std::endl;
 #include "PhilipsDictionary.h"
   } else {
-    std::cout << "no fnWhatever" << std::endl;
+  //  std::cout << "no fnWhatever" << std::endl;
     /**
     wxString file = GetDictionaryDir() + _T("/") + wxString(mFilename.c_str(), wxConvLocal);
     std::ifstream input(file.mb_str(wxConvLocal));
